var foo = 42;
var bar = "ok";
var _ = {
	foo: foo,
	bar: bar
};

export { bar, _ as default, foo };
